import React, { useState } from "react";
import Modal from "react-modal";
import CustomVideoModal from "./CustomVideoModal";
import { UrlType, getUrlType } from "../../util/Helper";
import { FaTimes } from "react-icons/fa";
import { Button } from "@mui/material";
import CustomLightBox from "./CustomLightBox";
Modal.setAppElement("#root"); // Important for accessibility

const AboutUsLightbox = ({ urls }) => {
  const [isLightboxOpen, setIsLightboxOpen] = useState(false);
  const [lightboxIndex, setLightboxIndex] = useState(0);
  const [isVideoModalOpen, setIsVideoModalOpen] = useState(false);
  const [videoUrl, setVideoUrl] = useState("");
  const [isSeeAllModalOpen, setIsSeeAllModalOpen] = useState(false);
  const limit = 6;

  const handleClick = (url, type, index) => {
    try {
      if (type === UrlType.IMAGE) {
        setLightboxIndex(index);
        setIsLightboxOpen(true);
      } else if (type === UrlType.VIDEO) {
        setVideoUrl(url);
        setIsVideoModalOpen(true);
      }
    } catch (error) {
      console.error("Error handling click:", error);
    }
  };

  const renderUrls = () => {
    try {
      return urls.slice(0, limit).map((url, index) => {
        const type = getUrlType(url);
        return (
          <div key={index} onClick={() => handleClick(url, type, index)} className="parent_div">
            {type === UrlType.IMAGE ? (
              <img
                src={url}
                alt="work evidence"
              />
            ) : (
              <video className="video_data" src={url} />
            )}
          </div>
        );
      });
    } catch (error) {
      console.error("Error rendering URLs:", error);
      return null;
    }
  };

  const images = urls
    ?.filter((url) => getUrlType(url) === UrlType.IMAGE)
    ?.map((url) => ({ src: url }));

  const gotoPrevious = () => {
    // Calculate the previous index
    const newIndex = (lightboxIndex + images?.length - 1) % images?.length;
    setLightboxIndex(newIndex);
  };

  const gotoNext = () =>
    setLightboxIndex((prevIndex) => (prevIndex + 1) % images?.length);

  return (
    <div className="main-lightbox">
      <div className="all-images">
        {renderUrls()}
        {urls.length > limit && (
          <Button onClick={() => setIsSeeAllModalOpen(true)}>See All</Button>
        )}
      </div>

      {isLightboxOpen && (
        <>
          <CustomLightBox lightboxOpen={isLightboxOpen} currentImages={images} currentImageIndex={lightboxIndex} handleCloseLightbox={() => setIsLightboxOpen(false)} gotoNext={gotoNext} gotoPrevious={gotoPrevious} />
        </>
      )}

      {isVideoModalOpen && (
        <CustomVideoModal
          isOpen={isVideoModalOpen}
          videoUrl={videoUrl}
          onClose={() => setIsVideoModalOpen(false)}
        />
      )}
      <Modal
        isOpen={isSeeAllModalOpen}
        onRequestClose={() => setIsSeeAllModalOpen(false)}
        contentLabel="All Images Modal"
      >
        <button
          onClick={() => setIsSeeAllModalOpen(false)}
          className="about_lightbox_closeButton"
          aria-label="Close"
        >
          <FaTimes />
        </button>
        <div className="about_lightbox_all-images-modal">
          {urls.map((url, index) => {
            const type = getUrlType(url);
            return (
              <div key={index} onClick={() => handleClick(url, type, index)} className="parent_div">
                {type === UrlType.IMAGE ? (
                  <img
                    src={url}
                    alt="work evidence"
                  />
                ) : (
                  <video className="video_data" src={url} />
                )}
              </div>
            );
          })}
        </div>
      </Modal>
    </div>
  );
};

export default AboutUsLightbox;
